@@ -1,7 +1,5 @@
-from typing import Any
-
 from django.contrib import admin
-from django.db.models import Sum
+from django.db.models import Prefetch, Q
 from mptt.admin import MPTTModelAdmin
 
 from hordak.models import TransactionCsvImport, TransactionCsvImportColumn
@@ -9,49 +7,80 @@ from hordak.models import TransactionCsvImport, TransactionCsvImportColumn
 from . import models
 
 
-def admin_attr_decorator(func: Any):
-    return func
+try:  # SubquerySum is quicker, but django-sql-utils can remain as optional dependency.
+    from sql_util.utils import SubquerySum as Sum
+
+    legs_filter = Q(amount__lt=0)
+except ImportError:
+    from django.db.models import Sum
+
+    legs_filter = Q(legs__amount__lt=0)
 
 
 @admin.register(models.Account)
 class AccountAdmin(MPTTModelAdmin):
-    list_display = ("name", "code_", "type_", "balance")
+    list_display = (
+        "name",
+        "code_",
+        "type_",
+        "currencies",
+        "balance_sum",
+        "income",
+    )
     readonly_fields = ("balance",)
     raw_id_fields = ("parent",)
     search_fields = (
         "code",
         "full_code",
         "name",
+        "userprofile__email",
+        "subscribed_userprofile__email",
+        "userprofile__first_name",
+        "subscribed_userprofile__first_name",
+        "userprofile__last_name",
+        "subscribed_userprofile__last_name",
     )
     list_filter = ("type",)
 
-    @admin_attr_decorator
+    @admin.display(ordering="balance_sum")
     def balance(self, obj):
         return obj.balance()
 
-    balance.admin_order_field = "balance_sum"
+    @admin.display(ordering="balance_sum")
+    def balance_sum(self, obj):
+        if obj.balance_sum:
+            return -obj.balance_sum
+        return "-"
+
+    balance_sum.admin_order_field = "balance_sum"
+
+    @admin.display(ordering="income")
+    def income(self, obj):
+        if obj.income:
+            return -obj.income
+        return "-"
 
     def get_queryset(self, *args, **kwargs):
         return (
             super()
             .get_queryset(*args, **kwargs)
-            .annotate(balance_sum=Sum("legs__amount"))
+            .annotate(
+                balance_sum=Sum("legs__amount"),
+                income=Sum("legs__amount", filter=legs_filter),
+            )
         )
 
-    @admin_attr_decorator
+    @admin.display(ordering="full_code")
     def code_(self, obj):
         if obj.is_leaf_node():
             return obj.full_code or "-"
-        else:
-            return ""
+        return ""
 
-    code_.admin_order_field = "full_code"
-
-    @admin_attr_decorator
+    @admin.display(ordering="type")
     def type_(self, obj):
-        return models.Account.TYPES[obj.type]
-
-    type_.admin_order_field = "type"
+        if obj.type:
+            return models.Account.TYPES[obj.type]
+        return "-"
 
 
 class LegInline(admin.TabularInline):
@@ -69,19 +98,49 @@ class TransactionAdmin(admin.ModelAdmin):
         "total_amount",
         "credited_accounts",
         "uuid",
+        "date",
+        "description",
+    ]
+    list_filter = [
+        "description",
     ]
     readonly_fields = ("timestamp",)
     search_fields = ("legs__account__name",)
     inlines = [LegInline]
 
     def debited_accounts(self, obj):
-        return ", ".join([str(leg.account) for leg in obj.legs.debits()]) or None
-
-    def credited_accounts(self, obj):
-        return ", ".join([str(leg.account) for leg in obj.legs.credits()]) or None
+        return ", ".join([str(leg.account.name) for leg in obj.debit_legs]) or None
 
     def total_amount(self, obj):
-        return obj.legs.debits().aggregate(Sum("amount"))["amount__sum"]
+        return obj.total_amount
+
+    def credited_accounts(self, obj):
+        return ", ".join([str(leg.account.name) for leg in obj.credit_legs]) or None
+
+    def get_queryset(self, *args, **kwargs):
+        return (
+            super()
+            .get_queryset(*args, **kwargs)
+            .prefetch_related(
+                Prefetch(
+                    "legs",
+                    queryset=models.Leg.objects.filter(amount__gt=0).select_related(
+                        "account"
+                    ),
+                    to_attr="debit_legs",
+                ),
+                Prefetch(
+                    "legs",
+                    queryset=models.Leg.objects.filter(amount__lt=0).select_related(
+                        "account"
+                    ),
+                    to_attr="credit_legs",
+                ),
+            )
+            .annotate(
+                total_amount=Sum("legs__amount", filter=legs_filter),
+            )
+        )
 
 
 @admin.register(models.Leg)
@@ -96,6 +155,10 @@ class LegAdmin(admin.ModelAdmin):
         "account",
         "transaction",
     )
+    list_filter = (
+        "account__type",
+        "transaction__description",
+    )
 
 
 @admin.register(models.StatementImport)
