@@ -1,16 +1,20 @@
-from .transactions import (
-    TransactionCreateView,
-    TransactionsReconcileView,
-    CurrencyTradeView,
-    TransactionDeleteView,
-    UnreconcileView,
+from .accounts import (  # noqa
+    AccountCreateView,
+    AccountListView,
+    AccountTransactionsView,
+    AccountUpdateView,
 )
-
-from .accounts import AccountCreateView, AccountListView, AccountUpdateView, AccountTransactionsView
-from .statement_csv_import import (
-    CreateImportView,
-    SetupImportView,
+from .statement_csv_import import (  # noqa
     AbstractImportView,
+    CreateImportView,
     DryRunImportView,
     ExecuteImportView,
+    SetupImportView,
+)
+from .transactions import (  # noqa
+    CurrencyTradeView,
+    TransactionCreateView,
+    TransactionDeleteView,
+    TransactionsReconcileView,
+    UnreconcileView,
 )
